#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/e2fsprogs-scrub-update.sh - e2fsprogs-scrub parameter update script
#
# Creation:     2023-05-21 hb
# Last Update:  $Id: e2fsprogs-scrub-update.sh 102995 2023-05-22 07:08:46Z hbfl $
#
# Copyright (c) 2020-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------

package_name="e2fsprogs-scrub"

# include configlib
. /var/install/include/configlib

VERSION=3.4.0

# ---------------------------------------------------------------------------
# Set the default values for configuration
# ---------------------------------------------------------------------------
get_defaults()
{
    START_E2FSPROGS_SCRUB='no'

    E2FSPROGS_SCRUB_SCHEDULE_TIME='Sun *-*-* 03:10:00'
    E2FSPROGS_SCRUB_MAIL_ADDR="root@$(hostname -f)"
    E2FSPROGS_SCRUB_SNAP_SIZE_MB='256'
    E2FSPROGS_SCRUB_FSTRIM='no'
    E2FSPROGS_SCRUB_E2FSCK_OPTS=''
    E2FSPROGS_SCRUB_ALL='no'
}

# ---------------------------------------------------------------------------
# rename old variables
# ---------------------------------------------------------------------------
rename_old_variables()
{
    # read old values
    if [ -f /etc/config.d/${package_name} ]
    then
        /var/install/bin/backup-file --quiet ${package_name}
        . /etc/config.d/${package_name}
    fi
}

# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
make_config_file()
{
    internal_conf_file="${1}"
    {
    # -----------------------------------------------------------------------
    printgpl --conf "${package_name}" '2023-05-21' 'hbfl' 'Holger Bruenjes'
    # -----------------------------------------------------------------------
    echo "# e2fsprogs-scrub-VERSION ${VERSION}"
    # -----------------------------------------------------------------------
    printgroup 'Ext2FS progs scrub (general settings)'
    # -----------------------------------------------------------------------

    printvar 'START_E2FSPROGS_SCRUB'
    printcomment             "Start Ext2Fsprogs scrub: 'yes' or 'no'"


    printvar 'E2FSPROGS_SCRUB_SCHEDULE_TIME'
    printcomment             'Systemd Time'

    printvar 'E2FSPROGS_SCRUB_MAIL_ADDR'
    printcomment             'Mail addr from admin'

    printvar 'E2FSPROGS_SCRUB_SNAP_SIZE_MB'
    printcomment             'Snapshots size: default 256'

    printvar 'E2FSPROGS_SCRUB_FSTRIM'
    printcomment             'enable fstrim: yes or no'

    printvar 'E2FSPROGS_SCRUB_E2FSCK_OPTS'
    printcomment             'e2fsck option'

    printvar 'E2FSPROGS_SCRUB_ALL'
    printcomment             'scrub all: yes or no'

    # -----------------------------------------------------------------------
    printend
    # -----------------------------------------------------------------------
    } >  $internal_conf_file
    # Set rights
    chmod 0600 $internal_conf_file
    chown root $internal_conf_file
}

# ---------------------------------------------------------------------------
# Create the check.d file
# ---------------------------------------------------------------------------
make_check_file()
{
printgpl --check ${package_name} '2023-05-21' 'hbfl' >/etc/check.d/${package_name}
cat >>/etc/check.d/${package_name} <<EOF
# Variable                     OPT_VARIABLE           VARIABLE_N   VALUE

START_E2FSPROGS_SCRUB          -                      -            YESNO

E2FSPROGS_SCRUB_SCHEDULE_TIME  START_E2FSPROGS_SCRUB  -            ON_CALENDAR
E2FSPROGS_SCRUB_MAIL_ADDR      START_E2FSPROGS_SCRUB  -            MAILADDR  
E2FSPROGS_SCRUB_SNAP_SIZE_MB   START_E2FSPROGS_SCRUB  -            NUMERIC
E2FSPROGS_SCRUB_FSTRIM         START_E2FSPROGS_SCRUB  -            YESNO
E2FSPROGS_SCRUB_E2FSCK_OPTS    START_E2FSPROGS_SCRUB  -            NONE  
E2FSPROGS_SCRUB_ALL            START_E2FSPROGS_SCRUB  -            YESNO 
EOF

   # Set rights for check.d file
   chmod 0600 /etc/check.d/${package_name}
   chown root /etc/check.d/${package_name}
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------
main()
{
    get_defaults

    # write default config file
    make_config_file /etc/default.d/${package_name}

    # update from old version
    rename_old_variables

    # write new config file
    make_config_file /etc/config.d/${package_name}

    # write check.d file
    make_check_file

    exit 0
}

# ----------------------------------------------------------------------------
# call function main
# ----------------------------------------------------------------------------
main "${@}"

# ---------------------------------------------------------------------------
# end
#----------------------------------------------------------------------------
