#!/bin/sh
#----------------------------------------------------------------------------
# /var/install/config.d/e2fsprogs-scrub.sh - configuration generator script for e2fsprogs-scrub
#
# Creation:     2023-05-21 hb
# Last Update:  $Id: e2fsprogs-scrub.sh 102995 2023-05-22 07:08:46Z hbfl $
#
# Copyright (c) 2020-2023 Holger Bruenjes, holgerbruenjes(at)gmx(dot)net
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later
#----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib


package_name='e2fsprogs-scrub'

config_file=/etc/config.d/${package_name}
sysconfig_file=/etc/e2scrub.conf
timer_dir='/etc/systemd/system/e2scrub_all.timer.d'
timer_conf='75-update-time.conf'


VERSION=3.4.0

. ${config_file}

# ---------------------------------------------------------------------------
# timer start
# ---------------------------------------------------------------------------
timer_start()
{
    /usr/sbin/service daemon-reload
    /usr/sbin/service enable e2scrub_all.timer
    /usr/sbin/service start e2scrub_all.timer
}

# ---------------------------------------------------------------------------
# timer stop
# ---------------------------------------------------------------------------
timer_stop()
{
    /usr/sbin/service stop e2scrub_all.timer
    /usr/sbin/service disable e2scrub_all.timer
    /usr/bin/systemctl clean --what=state e2scrub_all.timer
    /usr/sbin/service daemon-reload
}

# ---------------------------------------------------------------------------
# remove schedule
# ---------------------------------------------------------------------------
remove_schedule()
{
    rm -f ${timer_dir}/${timer_conf}
    rmdir --ignore-fail-on-non-empty ${timer_dir} 2>/dev/null
}

# ---------------------------------------------------------------------------
# create schedule
# ---------------------------------------------------------------------------
create_schedule()
{
    # create cron job
    mkdir -p ${timer_dir}

    cat >${timer_dir}/${timer_conf} <<EOF
# ------------------------------------------------------------------------------
# ${timer_dir}/${timer_conf} generated by ${package_name} Version ${VERSION}
# 
#  Do not edit this file, edit /etc/config.d/${package_name}
#  Creation Date: ${EISDATE} Time: ${EISTIME}
# -------------------------------------------------------------------------------
[Timer]
OnCalendar=
OnCalendar=${E2FSPROGS_SCRUB_SCHEDULE_TIME}
EOF

}

# ---------------------------------------------------------------------------
# create sysconfig
# ---------------------------------------------------------------------------
create_config()
{
    if [ "${START_E2FSPROGS_SCRUB}" != "yes" ]
    then
        p_scrub=0
    fi
    if [ "${E2FSPROGS_SCRUB_FSTRIM}" != "no" ] 
    then 
        trim=1
    fi
    if [ "${E2FSPROGS_SCRUB_ALL}" != "no" ]
    then             
        all=1
    fi

    cat >${sysconfig_file} <<EOF
#----------------------------------------------------------------------------
#  ${sysconfig_file} generated by ${package_name} version: ${VERSION}
#
#  Do not edit this file, edit ${config_file}
#  Creation Date: ${EISDATE} Time: ${EISTIME}
#----------------------------------------------------------------------------
periodic_e2scrub=${p_scrub:-1}
recipient=${E2FSPROGS_SCRUB_MAIL_ADDR}
sender=e2scrub@$(hostname -f)
snap_size_mb=${E2FSPROGS_SCRUB_SNAP_SIZE_MB}
fstrim=${trim:-0}
e2fsck_opt="${E2FSPROGS_SCRUB_E2FSCK_OPTS}"
scrub_all=${all:-0}
EOF

}

# ---------------------------------------------------------------------------
# quiet suppress all normal output
# ---------------------------------------------------------------------------
myecho()
{
    if ! ${_quiet:-false}
    then
        mecho ${@}
    fi
}

# ---------------------------------------------------------------------------
# main
# ---------------------------------------------------------------------------

while [ ${#} -ne 0 ]
do
    case "$1" in
    --quiet)
        _quiet=true
        __quiet='--quiet'
        shift
        ;;
    *)
        _action=${1}
        shift
        ;;
    esac
done

    case "${_action}" in
    *)
        create_config

        if [ "${START_E2FSPROGS_SCRUB}" = "yes" ]
        then
            create_schedule
            timer_start
        else
            timer_stop
            remove_schedule
        fi
        ;;
    esac

# ---------------------------------------------------------------------------
# end
# ---------------------------------------------------------------------------
